@@ -1,7 +1,8 @@
 import re
 import sys
 from ctypes import *
-from DAQmxConfig import dot_h_file, lib_name
+
+import DAQmxConfig
 from DAQmxTypes import *
 
 class DAQError(Exception):
@@ -18,7 +19,7 @@ class DAQError(Exception):
     def __str__(self):
         return self.mess + '\n in function '+self.fname
 
-def catch_error(f):
+def catch_error_default(f):
     def mafunction(*arg):
         error = f(*arg)
         if error<0:
@@ -28,12 +29,36 @@ def catch_error(f):
         elif error>0:
             errBuff = create_string_buffer(2048)
             DAQmxGetErrorString (error, errBuff, 2048);
-            print "WARNING  :",error, "  ", errBuff.value.decode("utf-8")
+#            print "WARNING  :",error, "  ", errBuff.value.decode("utf-8")
             raise DAQError(error,errBuff.value.decode("utf-8"), f.__name__)
-
         return error
     return mafunction
 
+#def catch_error_DAQmxGetSys(f):
+#    """ Catch error if the first argument is not None"""
+#    default_f = catch_error_default(f)
+#    def mafunction(*args):
+#        if args[0] is not None:
+#            return default_f(*args)
+#        return f(*args)
+#    return mafunction
+
+def catch_error_buffer(f, data_pos):
+    """ Catch error only if the data arg is not None"""
+    default_f = catch_error_default(f)
+    def mafunction(*args):
+        if args[data_pos] is not None:
+            return default_f(*args)
+        return f(*args)
+    return mafunction
+
+def catch_error(f, name, arg_list, arg_name):
+#    if name.startswith("DAQmxGetSys"):
+#        return catch_error_DAQmxGetSys(f)
+    if 'data' in arg_name and 'bufferSize' in arg_name:
+        return catch_error_buffer(f, arg_name.index('data'))
+    return catch_error_default(f)
+
 
 def _add_keywords(arg_name):
     """ This function is used to create a decorator that add arg_name keywords to a function"""
@@ -44,17 +69,21 @@ def _add_keywords(arg_name):
     return locals()['add_keywords_decorator']
 
 
-if lib_name is not None:
-    if sys.platform.startswith('win'):        
-        DAQlib = windll.LoadLibrary(lib_name)
-    elif sys.platform.startswith('linux'):
-        DAQlib = cdll.LoadLibrary(lib_name)
-    # else other platforms will already have barfed importing DAQmxConfig
-else: # NIDAQmx is not installed on the machine. Use a dummy library
-    class _nothing():
-        def __getattr__(self, name):
-            return lambda *args:0
-    DAQlib = _nothing()
+#if lib_name is not None:
+#    if sys.platform.startswith('win'):        
+#        DAQlib = windll.LoadLibrary(lib_name)
+#        DAQlib_variadic = cdll.LoadLibrary(lib_name)
+#    elif sys.platform.startswith('linux'):
+#        DAQlib = cdll.LoadLibrary(lib_name)
+#        DAQlib_variadic = DAQlib
+#else: # NIDAQmx is not installed on the machine. Use a dummy library
+#    class _nothing():
+#        def __getattr__(self, name):
+#            return lambda *args:0
+#    DAQlib = _nothing()
+#    DAQlib_variadic = DAQlib
+DAQlib, DAQlib_variadic = DAQmxConfig.get_lib()
+
 
 ######################################
 # Array
@@ -78,12 +107,13 @@ else:
         return eval('numpy.'+string.lower())
     def array_type(string):
         """ Returns the array type required by ctypes when numpy is used """
-        return numpy.ctypeslib.ndpointer(dtype = numpy_conversion(string))
+        return numpy.ctypeslib.ndpointer(dtype = numpy_conversion(string),
+                                         flags=('C_CONTIGUOUS','WRITEABLE'))
 
 ################################
 #Read the .h file and convert the function for python
 ################################
-include_file = open(dot_h_file,'r') #Open NIDAQmx.h file
+include_file = open(DAQmxConfig.dot_h_file,'r') #Open NIDAQmx.h file
 
 ################################
 # Regular expression to parse the NIDAQmx.h file
@@ -94,7 +124,7 @@ include_file = open(dot_h_file,'r') #Open NIDAQmx.h file
 # group in which the name of the variable is defined
 
 
-fonction_parser = re.compile(r'.* (DAQ\S+)\s*\((.*)\);')
+function_parser = re.compile(r'__CFUNC.* (DAQ\S+)\s*\((.*)\);')
 const_char = re.compile(r'(const char)\s*([^\s]*)\[\]')
 string_type = '|'.join(['int8','uInt8','int16','uInt16','int32','uInt32','float32','float64','int64','uInt64','bool32','TaskHandle'])
 
@@ -124,12 +154,13 @@ call_back_A = [(re.compile(r'(DAQmxEveryNSamplesEventCallbackPtr)\s*([^\s]*)'),D
 call_back_B = [(re.compile(r'(DAQmxDoneEventCallbackPtr)\s*([^\s]*)'),DAQmxDoneEventCallbackPtr,2)]
 call_back_C = [(re.compile(r'(DAQmxSignalEventCallbackPtr)\s*([^\s]*)'),DAQmxSignalEventCallbackPtr,2)]
 
+variadic = [(re.compile(r'\.\.\.'), "variadic", None)]
 
 # Create a list with all regular expressions
 c_to_ctype_map = []
 for l in [const_char, simple_type, pointer_type, pointer_type_array, pointer_type_array,
         pointer_type_2,char_etoile, void_etoile,char_array, 
-          call_back_A, call_back_B, call_back_C]:
+          call_back_A, call_back_B, call_back_C, variadic]:
     c_to_ctype_map.extend(l)
 
 
@@ -142,34 +173,53 @@ function_dict = {}
 
 
 def _define_function(name, arg_list, arg_name):
-    # Record details of function
-    function_dict[name] = {'arg_type':arg_list, 'arg_name':arg_name}
+    if "variadic" in arg_list:
+        _define_variadic_function(name, arg_list, arg_name)
+        return
     # Fetch C function and apply argument checks
     cfunc = getattr(DAQlib, name)
+    if DAQmxConfig.NIDAQmxBase and 'Base' in name :
+        name = name[:5]+name[9:]  
     setattr(cfunc, 'argtypes', arg_list)
     # Create error-raising wrapper for C function and add to module's dict
-    func = _add_keywords(arg_name)(catch_error(cfunc))
+    func = _add_keywords(arg_name)(catch_error(cfunc, name, arg_list, arg_name))
     func.__name__ = name
     func.__doc__ = '%s(%s) -> error.' % (name, ', '.join(arg_name))
     globals()[name] = func
+    # Record details of function
+    function_dict[name] = {'arg_type':arg_list, 'arg_name':arg_name}
+
+def _define_variadic_function(name, arg_list, arg_name):
+    cfunc = getattr(DAQlib_variadic, name)
+    if DAQmxConfig.NIDAQmxBase and 'Base' in name :
+        name = name[:5]+name[9:]    
+    func = _add_keywords(arg_name)(catch_error(cfunc, name, arg_list, arg_name))
+    func.__name__ = name
+    func.__doc__ = '%s(%s) -> error.' % (name, ', '.join(arg_name))
+    globals()[name] = func
+    function_dict[name] = {'arg_type':arg_list, 'arg_name':arg_name}
 
 
-
+argsplit = re.compile(', |,')
 for line in include_file:
-    line = line[0:-1]
-    if '__CFUNC' in line and fonction_parser.match(line):
-        name = fonction_parser.match(line).group(1)
+    fn_match = function_parser.search(line[:-1])
+    if fn_match and not line.startswith('//'):
+        name = fn_match.group(1)
         function_list.append(name)
-        arg_string = fonction_parser.match(line).group(2)
+        arg_string = fn_match.group(2)
         arg_list=[]
         arg_name = []
-        for arg in re.split(', |,',arg_string): # Almost everywhere there is a space after the comma
-            for (reg_expr, new_type, groug_nb) in c_to_ctype_map:
+        for arg in argsplit.split(arg_string): # Almost everywhere there is a space after the comma
+            for (reg_expr, new_type, group_nb) in c_to_ctype_map:
                 reg_expr_result = reg_expr.search(arg)
                 if reg_expr_result is not None:
+                    if new_type=="variadic":
+                        arg_list.append(new_type)
+                        arg_name.append("*args")
+                        break
                     arg_list.append(new_type)
-                    arg_name.append(reg_expr_result.group(groug_nb))
-                    break # break the for loop
+                    arg_name.append(reg_expr_result.group(group_nb))
+                    break # break the for loop    
         _define_function(name, arg_list, arg_name)
 
 include_file.close()
