@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
 
+import DAQmxConfig
+
 from DAQmxTypes import *
 from DAQmxConstants import *
 from DAQmxFunctions import *
 from Task import Task
 
 
-__version_info__ = (1, 2, 5, 2)
+__version_info__ = (1, 3)
 __version__ = '.'.join(str(num) for num in __version_info__)
 
 __author__ =u'Pierre Cladé'
